﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Threading.Tasks;
using SQLite;
using Todolist.Commons;
using Todolist.Models;

namespace Todolist.Helpers
{
    public class DBHelper
    {
        private static DBHelper _instance;
        private SQLiteAsyncConnection _conn;

        public static DBHelper Instance
        {
            get { return _instance = _instance ?? new DBHelper(); }
        }

        public async Task InitAsync()
        {
            _conn = new SQLiteAsyncConnection("todoDB");
            var result = await _conn.CreateTableAsync<TodoModel>();
            if (await _conn.Table<TodoModel>().CountAsync() == 0)
            {
                await AddTodoAsync(new TodoModel { Id = 0, Title = "Seed1", Content = "seed1", Created = DateTime.Now, Status = StaticDatas.WORKING });
                await AddTodoAsync(new TodoModel { Id = 1, Title = "Seed2", Content = "seed2", Created = DateTime.Now, Status = StaticDatas.COMPLETE });
            }
        }

        public async Task AddTodoAsync(TodoModel addItem)
        {
            var result = await _conn.InsertAsync(addItem);
            if (result == 0)
            {
                StaticFunctions.MsgBox("추가 실패");
            }
        }

        public async Task DeleteTodoAsync(TodoModel removeItem)
        {
            var result = await _conn.DeleteAsync(removeItem);
            if (result == 0)
            {
                StaticFunctions.MsgBox("삭제 실패");
            }
        }

        public async Task UpdateTodoAsync(TodoModel updateItem)
        {
            var result = await _conn.UpdateAsync(updateItem);

            if (result == 0)
            {
                StaticFunctions.MsgBox("갱신 실패");
            }
        }

        public AsyncTableQuery<TodoModel> TodoTable
        {
            get { return _conn.Table<TodoModel>(); }
        }
    }
}
